==> ove-pro-test-18.3.12.tgz: package/es/ToolBar/partTool.js <==
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import { Icon } from "@blueprintjs/core";
// import { Checkbox, Button } from "@blueprintjs/core";
import React from "react";
// import { connect } from "react-redux";
// import { convertRangeTo1Based } from "@teselagen/range-utils";
//import { partIcon } from "teselagen-react-components";
import ToolbarItem from "./ToolbarItem";
import { connectToEditor } from "../withEditorProps";
import { PartTagSearch } from "../helperComponents/partTagSearch";
export default connectToEditor(function (_ref) {
  var _ref$annotationVisibi = _ref.annotationVisibility,
    annotationVisibility = _ref$annotationVisibi === void 0 ? {} : _ref$annotationVisibi,
    _ref$toolBar = _ref.toolBar,
    toolBar = _ref$toolBar === void 0 ? {} : _ref$toolBar;
  return {
    toggled: annotationVisibility.parts,
    isOpen: toolBar.openItem === "partTool"
  };
})(function (_ref2) {
  var allPartTags = _ref2.allPartTags,
    editTagsLink = _ref2.editTagsLink,
    toolbarItemProps = _ref2.toolbarItemProps,
    toggled = _ref2.toggled,
    annotationVisibilityToggle = _ref2.annotationVisibilityToggle,
    isOpen = _ref2.isOpen;
  return /*#__PURE__*/React.createElement(ToolbarItem, _extends({
    Icon: /*#__PURE__*/React.createElement(Icon, {
      icon: "doughnut-chart"
    }),
    onIconClick: function onIconClick() {
      annotationVisibilityToggle("parts");
    },
    toggled: toggled,
    editTagsLink: editTagsLink,
    allPartTags: allPartTags,
    tooltip: "Show parts",
    tooltipToggled: "Hide parts",
    noDropdownIcon: !allPartTags,
    Dropdown: PartTagSearch,
    dropdowntooltip: (!isOpen ? "Show" : "Hide") + " Part Options"
  }, toolbarItemProps));
});

==> ove-pro-test-18.3.15.tgz: package/es/ToolBar/partTool.js <==
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import { Icon } from "@blueprintjs/core";
// import { Checkbox, Button } from "@blueprintjs/core";
import React from "react";
// import { connect } from "react-redux";
// import { convertRangeTo1Based } from "@teselagen/range-utils";
//import { partIcon } from "teselagen-react-components";
import ToolbarItem from "./ToolbarItem";
import { connectToEditor } from "../withEditorProps";
import { PartTagSearch } from "../helperComponents/partTagSearch";
export default connectToEditor(function (_ref) {
  var _ref$annotationVisibi = _ref.annotationVisibility,
    annotationVisibility = _ref$annotationVisibi === void 0 ? {} : _ref$annotationVisibi,
    _ref$toolBar = _ref.toolBar,
    toolBar = _ref$toolBar === void 0 ? {} : _ref$toolBar;
  return {
    toggled: annotationVisibility.parts,
    isOpen: toolBar.openItem === "partTool"
  };
})(function (_ref2) {
  var allPartTags = _ref2.allPartTags,
    editTagsLink = _ref2.editTagsLink,
    toolbarItemProps = _ref2.toolbarItemProps,
    toggled = _ref2.toggled,
    annotationVisibilityToggle = _ref2.annotationVisibilityToggle,
    isOpen = _ref2.isOpen;
  return /*#__PURE__*/React.createElement(ToolbarItem, _extends({
    Icon: /*#__PURE__*/React.createElement(Icon, {
      icon: "doughnut-chart"
    }),
    onIconClick: function onIconClick() {
      annotationVisibilityToggle("parts");
    },
    toggled: toggled,
    editTagsLink: editTagsLink,
    allPartTags: allPartTags,
    tooltip: "显示 parts",
    tooltipToggled: "隐藏 parts",
    noDropdownIcon: !allPartTags,
    Dropdown: PartTagSearch,
    dropdowntooltip: (!isOpen ? "显示" : "隐藏") + " Part 选项"
  }, toolbarItemProps));
});
